@@ -18,7 +18,7 @@ PYTHON_CLIENT = "Python Client"
 
 def parse_timestamp_str(ts: str) -> Timestamp or None:
     """
-    Parses a date/time in YYYY-MM-ddTHH:mm:ss[%f] format.
+    Parses a date/time in YYYY-MM-dd[THH:mm:ss[%f]] format.
 
     :param ts: The timestamp.
     :type ts: str
