@@ -10,22 +10,22 @@ from archipelagos.common.protobuf.common.data.collection import Collection_pb2
 from archipelagos.common.protobuf.common.data.collection import CollectionRequest_pb2, CollectionResponse_pb2
 from archipelagos.common.protobuf.common.data.collection import CollectionMetadataResponse_pb2
 from archipelagos.common.protobuf.common.data.collection import CollectionMetadataRequest_pb2
-from archipelagos.common.protobuf.common.data import DataEntry_pb2
-from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.data import _valid_feature_value, _feature_value_equals
 from archipelagos.common.data import _get_feature_value, _get_feature_value_from_proto
+from archipelagos.common.data import Frequency, is_valid_token
+from archipelagos.common.protobuf.common.data import DataEntry_pb2
+from archipelagos.common.protobuf.common import Timestamp_pb2
 from archipelagos.common.platform import ClientType
 
-from archipelagos.common.data import Frequency, is_valid_token
-
-import array
 from typing import Dict, List
 from datetime import datetime
 from pandas import Timestamp
+import array
 
 
 class CollectionMetadata:
-    """Represents the metadata about a collection.
+    """
+    Represents the metadata about a collection.
     """
     def __init__(self,
                  source: str,
